Structs
- Error
Message Body ErrorMessageBodyrepresents the error response body.- Init
Message Body InitMessageBodyrepresents the message body for the “init” message.- Message
- Message represents a message sent from Src node to Dest node.
The body is stored as parsed
MessageBodyalong with the original string and all extra fields. - Message
Body MessageBodyrepresents the reserved keys for a message body.